PyWBEM v0.8
-----------

This directory contains the distribution archives for the development
releases and release candidates of PyWBEM v0.8.

Unfortunately, we screwed up during the release of v0.8.0 to PyPI and
because of the strict policy of PyPI not to upload the same version
of a file again, so the first final release has become v0.8.1.

The NEWS file in each distribution archive describes the changes up to that
point.

The distribution archives for the v0.8.x releases are namedi
`pywbem-0.8.<x>.tar.gz`.

Earlier versions are still available for reference, and their file names
end with `dev*.zip` or `rc*.zip`.

Please report any issues using the
[PyWBEM issue tracker on GitHub](https://github.com/pywbem/pywbem/issues).
